.. _developer_reference:

********************
Developer Reference
********************

.. contents::
   :depth: 3
   :local:


.. include:: developer_information/developer_reference/framework_overview.rst

-----------------

.. include:: developer_information/developer_reference/plugins.rst

-----------------

.. include:: developer_information/developer_reference/revent.rst

-----------------

.. include:: developer_information/developer_reference/serialization.rst

-----------------

.. include:: developer_information/developer_reference/contributing.rst

